@@ -7,13 +7,13 @@ the more appropriate and useful type for most collections.
 #![cfg(any(feature = "alloc", feature = "std"))]
 
 use crate::{
-	bits::Bits,
 	cursor::{
 		BigEndian,
 		Cursor,
 	},
 	pointer::BitPtr,
 	slice::BitSlice,
+	store::BitStore,
 	vec::BitVec,
 };
 
@@ -116,8 +116,9 @@ can. It is useful for fixed-size collections without lifetime tracking.
 - `C: Cursor`: An implementor of the [`Cursor`] trait. This type is used to
   convert semantic indices into concrete bit positions in elements, and store or
   retrieve bit values from the storage type.
-- `T: Bits`: An implementor of the [`Bits`] trait: `u8`, `u16`, `u32`, or `u64`.
-  This is the actual type in memory that the box will use to store data.
+- `T: BitStore`: An implementor of the [`BitStore`] trait: `u8`, `u16`, `u32`,
+  or `u64` (64-bit systems only). This is the actual type in memory that the box
+  will use to store data.
 
 # Safety
 
@@ -134,13 +135,13 @@ to and from `BitSlice`, and to/from `BitVec`.
 **/
 #[repr(C)]
 pub struct BitBox<C = BigEndian, T = u8>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	_cursor: PhantomData<C>,
 	pointer: BitPtr<T>,
 }
 
 impl<C, T> BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	/// Constructs an empty boxed bitslice.
 	///
 	/// # Returns
@@ -204,12 +205,12 @@ where C: Cursor, T: Bits {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let src: &[u8] = &[5, 10];
-	/// let bv: BitBox = src.into();
-	/// assert!(bv[5]);
-	/// assert!(bv[7]);
-	/// assert!(bv[12]);
-	/// assert!(bv[14]);
+	/// let src = [5, 10];
+	/// let bb: BitBox = BitBox::from_slice(&src[..]);
+	/// assert!(bb[5]);
+	/// assert!(bb[7]);
+	/// assert!(bb[12]);
+	/// assert!(bb[14]);
 	/// ```
 	pub fn from_slice(slice: &[T]) -> Self {
 		assert!(slice.len() <= BitPtr::<T>::MAX_ELTS, "Box overflow");
@@ -231,9 +232,8 @@ where C: Cursor, T: Bits {
 	/// ```rust
 	/// use bitvec::prelude::*;
 	///
-	/// let src: &[u8] = &[0, !0];
-	/// let bs: &BitSlice = src.into();
-	/// let bb = BitBox::from_bitslice(bs);
+	/// let src = [0u8, !0];
+	/// let bb = BitBox::<BigEndian, _>::from_bitslice(src.as_bitslice());
 	/// assert_eq!(bb.len(), 16);
 	/// assert!(bb.some());
 	/// ```
@@ -378,7 +378,7 @@ where C: Cursor, T: Bits {
 	pub fn leak<'a>(self) -> &'a mut BitSlice<C, T> {
 		let out = self.bitptr();
 		mem::forget(self);
-		out.into()
+		out.into_bitslice_mut()
 	}
 
 	/// Changes the cursor on a box handle, without changing the data it
@@ -408,7 +408,7 @@ where C: Cursor, T: Bits {
 	///
 	/// The slice of bits behind the box.
 	pub fn as_bitslice(&self) -> &BitSlice<C, T> {
-		self.pointer.into()
+		self.pointer.into_bitslice()
 	}
 
 	/// Accesses the `BitSlice<C, T>` to which the `BitBox` refers.
@@ -421,7 +421,7 @@ where C: Cursor, T: Bits {
 	///
 	/// The slice of bits behind the box.
 	pub fn as_mut_bitslice(&mut self) -> &mut BitSlice<C, T> {
-		self.pointer.into()
+		self.pointer.into_bitslice_mut()
 	}
 
 	/// Gives read access to the `BitPtr<T>` structure powering the box.
@@ -467,21 +467,21 @@ where C: Cursor, T: Bits {
 }
 
 impl<C, T> Borrow<BitSlice<C, T>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn borrow(&self) -> &BitSlice<C, T> {
-		&*self
+		self.as_bitslice()
 	}
 }
 
 impl<C, T> BorrowMut<BitSlice<C, T>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn borrow_mut(&mut self) -> &mut BitSlice<C, T> {
-		&mut *self
+		self.as_mut_bitslice()
 	}
 }
 
 impl<C, T> Clone for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn clone(&self) -> Self {
 		let (e, h, t) = self.bitptr().region_data();
 		let new_box = self.do_with_box(Clone::clone);
@@ -495,122 +495,122 @@ where C: Cursor, T: Bits {
 }
 
 impl<C, T> Eq for BitBox<C, T>
-where C: Cursor, T: Bits {}
+where C: Cursor, T: BitStore {}
 
 impl<C, T> Ord for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn cmp(&self, rhs: &Self) -> Ordering {
 		self.as_bitslice().cmp(rhs.as_bitslice())
 	}
 }
 
 impl<A, B, C, D> PartialEq<BitBox<C, D>> for BitBox<A, B>
-where A: Cursor, B: Bits, C: Cursor, D: Bits {
+where A: Cursor, B: BitStore, C: Cursor, D: BitStore {
 	fn eq(&self, rhs: &BitBox<C, D>) -> bool {
 		self.as_bitslice().eq(rhs.as_bitslice())
 	}
 }
 
 impl<A, B, C, D> PartialEq<BitSlice<C, D>> for BitBox<A, B>
-where A: Cursor, B: Bits, C: Cursor, D: Bits {
+where A: Cursor, B: BitStore, C: Cursor, D: BitStore {
 	fn eq(&self, rhs: &BitSlice<C, D>) -> bool {
 		self.as_bitslice().eq(rhs)
 	}
 }
 
 impl<A, B, C, D> PartialEq<BitBox<C, D>> for BitSlice<A, B>
-where A: Cursor, B: Bits, C: Cursor, D: Bits {
+where A: Cursor, B: BitStore, C: Cursor, D: BitStore {
 	fn eq(&self, rhs: &BitBox<C, D>) -> bool {
 		self.eq(rhs.as_bitslice())
 	}
 }
 
 impl<A, B, C, D> PartialOrd<BitBox<C, D>> for BitBox<A, B>
-where A: Cursor, B: Bits, C: Cursor, D: Bits {
+where A: Cursor, B: BitStore, C: Cursor, D: BitStore {
 	fn partial_cmp(&self, rhs: &BitBox<C, D>) -> Option<Ordering> {
 		self.as_bitslice().partial_cmp(rhs.as_bitslice())
 	}
 }
 
 impl<A, B, C, D> PartialOrd<BitSlice<C, D>> for BitBox<A, B>
-where A: Cursor, B: Bits, C: Cursor, D: Bits {
+where A: Cursor, B: BitStore, C: Cursor, D: BitStore {
 	fn partial_cmp(&self, rhs: &BitSlice<C, D>) -> Option<Ordering> {
 		self.as_bitslice().partial_cmp(rhs)
 	}
 }
 
 impl<A, B, C, D> PartialOrd<BitBox<C, D>> for BitSlice<A, B>
-where A: Cursor, B: Bits, C: Cursor, D: Bits {
+where A: Cursor, B: BitStore, C: Cursor, D: BitStore {
 	fn partial_cmp(&self, rhs: &BitBox<C, D>) -> Option<Ordering> {
 		self.partial_cmp(rhs.as_bitslice())
 	}
 }
 
 impl<C, T> AsMut<BitSlice<C, T>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn as_mut(&mut self) -> &mut BitSlice<C, T> {
 		self.as_mut_bitslice()
 	}
 }
 
 impl<C, T> AsMut<[T]> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn as_mut(&mut self) -> &mut [T] {
 		self.as_mut_bitslice().as_mut()
 	}
 }
 
 impl<C, T> AsRef<BitSlice<C, T>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn as_ref(&self) -> &BitSlice<C, T> {
 		self.as_bitslice()
 	}
 }
 
 impl<C, T> AsRef<[T]> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn as_ref(&self) -> &[T] {
 		self.as_bitslice().as_ref()
 	}
 }
 
 impl<C, T> From<&BitSlice<C, T>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn from(src: &BitSlice<C, T>) -> Self {
 		Self::from_bitslice(src)
 	}
 }
 
 impl<C, T> From<&[T]> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn from(src: &[T]) -> Self {
 		Self::from_slice(src)
 	}
 }
 
 impl<C, T> From<BitVec<C, T>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn from(src: BitVec<C, T>) -> Self {
 		src.into_boxed_bitslice()
 	}
 }
 
 impl<C, T> From<Box<[T]>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn from(src: Box<[T]>) -> Self {
 		Self::from_boxed_slice(src)
 	}
 }
 
 impl<C, T> Into<Box<[T]>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn into(self) -> Box<[T]> {
 		self.into_boxed_slice()
 	}
 }
 
 impl<C, T> Default for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn default() -> Self {
 		Self {
 			_cursor: PhantomData,
@@ -620,46 +620,46 @@ where C: Cursor, T: Bits {
 }
 
 impl<C, T> Debug for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn fmt(&self, f: &mut Formatter) -> fmt::Result {
 		f.write_str("BitBox<")?;
 		f.write_str(C::TYPENAME)?;
 		f.write_str(", ")?;
 		f.write_str(T::TYPENAME)?;
 		f.write_str("> ")?;
-		Display::fmt(&**self, f)
+		Display::fmt(self.as_bitslice(), f)
 	}
 }
 
 impl<C, T> Display for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-		Display::fmt(&**self, f)
+		Display::fmt(self.as_bitslice(), f)
 	}
 }
 
 impl<C, T> Hash for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn hash<H: Hasher>(&self, hasher: &mut H) {
 		self.as_bitslice().hash(hasher)
 	}
 }
 
 impl<C, T> IntoIterator for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Item = bool;
 	type IntoIter = IntoIter<C, T>;
 
 	fn into_iter(self) -> Self::IntoIter {
 		IntoIter {
-			iterator: self.bitptr(),
-			_original: self,
+			region: self.bitptr(),
+			bitbox: self,
 		}
 	}
 }
 
 impl<'a, C, T> IntoIterator for &'a BitBox<C, T>
-where C: Cursor, T: 'a + Bits {
+where C: Cursor, T: 'a + BitStore {
 	type Item = bool;
 	type IntoIter = <&'a BitSlice<C, T> as IntoIterator>::IntoIter;
 
@@ -670,14 +670,14 @@ where C: Cursor, T: 'a + Bits {
 
 /// `BitBox` is safe to move across thread boundaries, as is `&mut BitBox`.
 unsafe impl<C, T> Send for BitBox<C, T>
-where C: Cursor, T: Bits {}
+where C: Cursor, T: BitStore {}
 
 /// `&BitBox` is safe to move across thread boundaries.
 unsafe impl<C, T> Sync for BitBox<C, T>
-where C: Cursor, T: Bits {}
+where C: Cursor, T: BitStore {}
 
 impl<C, T> Add<Self> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = Self;
 
 	fn add(mut self, addend: Self) -> Self::Output {
@@ -687,14 +687,14 @@ where C: Cursor, T: Bits {
 }
 
 impl<C, T> AddAssign for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn add_assign(&mut self, addend: Self) {
-		**self += &*addend
+		self.as_mut_bitslice().add_assign(addend.as_bitslice())
 	}
 }
 
 impl<C, T, I> BitAnd<I> for BitBox<C, T>
-where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
+where C: Cursor, T: BitStore, I: IntoIterator<Item=bool> {
 	type Output = Self;
 
 	fn bitand(mut self, rhs: I) -> Self::Output {
@@ -704,14 +704,14 @@ where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
 }
 
 impl<C, T, I> BitAndAssign<I> for BitBox<C, T>
-where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
+where C: Cursor, T: BitStore, I: IntoIterator<Item=bool> {
 	fn bitand_assign(&mut self, rhs: I) {
-		**self &= rhs;
+		self.as_mut_bitslice().bitand_assign(rhs);
 	}
 }
 
 impl<C, T, I> BitOr<I> for BitBox<C, T>
-where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
+where C: Cursor, T: BitStore, I: IntoIterator<Item=bool> {
 	type Output = Self;
 
 	fn bitor(mut self, rhs: I) -> Self::Output {
@@ -721,14 +721,14 @@ where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
 }
 
 impl<C, T, I> BitOrAssign<I> for BitBox<C, T>
-where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
+where C: Cursor, T: BitStore, I: IntoIterator<Item=bool> {
 	fn bitor_assign(&mut self, rhs: I) {
-		**self |= rhs;
+		self.as_mut_bitslice().bitor_assign(rhs);
 	}
 }
 
 impl<C, T, I> BitXor<I> for BitBox<C, T>
-where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
+where C: Cursor, T: BitStore, I: IntoIterator<Item=bool> {
 	type Output = Self;
 
 	fn bitxor(mut self, rhs: I) -> Self::Output {
@@ -738,165 +738,168 @@ where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
 }
 
 impl<C, T, I> BitXorAssign<I> for BitBox<C, T>
-where C: Cursor, T: Bits, I: IntoIterator<Item=bool> {
+where C: Cursor, T: BitStore, I: IntoIterator<Item=bool> {
 	fn bitxor_assign(&mut self, rhs: I) {
-		**self ^= rhs;
+		self.as_mut_bitslice().bitxor_assign(rhs);
 	}
 }
 
 impl<C, T> Deref for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Target = BitSlice<C, T>;
 
 	fn deref(&self) -> &Self::Target {
-		self.pointer.into()
+		self.as_bitslice()
 	}
 }
 
 impl<C, T> DerefMut for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn deref_mut(&mut self) -> &mut Self::Target {
-		self.pointer.into()
+		self.as_mut_bitslice()
 	}
 }
 
 impl<C, T> Drop for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn drop(&mut self) {
-		let ptr = self.as_mut_bitslice().as_mut_ptr();
-		let len = self.as_bitslice().len();
+		let ptr = self.as_mut_slice().as_mut_ptr();
+		let len = self.as_slice().len();
 		//  Run the `Box<[T]>` destructor.
-		drop(unsafe { Vec::from_raw_parts(ptr, len, len).into_boxed_slice() });
+		drop(unsafe { Vec::from_raw_parts(ptr, 0, len) }.into_boxed_slice());
 	}
 }
 
 impl<C, T> Index<usize> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = bool;
 
 	fn index(&self, index: usize) -> &Self::Output {
-		&(**self)[index]
+		&self.as_bitslice()[index]
 	}
 }
 
 impl<C, T> Index<Range<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = BitSlice<C, T>;
 
 	fn index(&self, range: Range<usize>) -> &Self::Output {
-		&(**self)[range]
+		&self.as_bitslice()[range]
 	}
 }
 
 impl<C, T> IndexMut<Range<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn index_mut(&mut self, range: Range<usize>) -> &mut Self::Output {
-		&mut (**self)[range]
+		&mut self.as_mut_bitslice()[range]
 	}
 }
 
 impl<C, T> Index<RangeFrom<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = BitSlice<C, T>;
 
 	fn index(&self, range: RangeFrom<usize>) -> &Self::Output {
-		&(**self)[range]
+		&self.as_bitslice()[range]
 	}
 }
 
 impl<C, T> IndexMut<RangeFrom<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn index_mut(&mut self, range: RangeFrom<usize>) -> &mut Self::Output {
-		&mut (**self)[range]
+		&mut self.as_mut_bitslice()[range]
 	}
 }
 
 impl<C, T> Index<RangeFull> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = BitSlice<C, T>;
 
-	fn index(&self, range: RangeFull) -> &Self::Output {
-		&(**self)[range]
+	fn index(&self, _: RangeFull) -> &Self::Output {
+		self.as_bitslice()
 	}
 }
 
 impl<C, T> IndexMut<RangeFull> for BitBox<C, T>
-where C: Cursor, T: Bits {
-	fn index_mut(&mut self, range: RangeFull) -> &mut Self::Output {
-		&mut (**self)[range]
+where C: Cursor, T: BitStore {
+	fn index_mut(&mut self, _: RangeFull) -> &mut Self::Output {
+		self.as_mut_bitslice()
 	}
 }
 
 impl<C, T> Index<RangeInclusive<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = BitSlice<C, T>;
 
 	fn index(&self, range: RangeInclusive<usize>) -> &Self::Output {
-		&(**self)[range]
+		&self.as_bitslice()[range]
 	}
 }
 
 impl<C, T> IndexMut<RangeInclusive<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn index_mut(&mut self, range: RangeInclusive<usize>) -> &mut Self::Output {
-		&mut (**self)[range]
+		&mut self.as_mut_bitslice()[range]
 	}
 }
 
 impl<C, T> Index<RangeTo<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = BitSlice<C, T>;
 
 	fn index(&self, range: RangeTo<usize>) -> &Self::Output {
-		&(**self)[range]
+		&self.as_bitslice()[range]
 	}
 }
 
 impl<C, T> IndexMut<RangeTo<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn index_mut(&mut self, range: RangeTo<usize>) -> &mut Self::Output {
-		&mut (**self)[range]
+		&mut self.as_mut_bitslice()[range]
 	}
 }
 
 impl<C, T> Index<RangeToInclusive<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = BitSlice<C, T>;
 
 	fn index(&self, range: RangeToInclusive<usize>) -> &Self::Output {
-		&(**self)[range]
+		&self.as_bitslice()[range]
 	}
 }
 
 impl<C, T> IndexMut<RangeToInclusive<usize>> for BitBox<C, T>
-where C: Cursor, T: Bits {
-	fn index_mut(&mut self, range: RangeToInclusive<usize>) -> &mut Self::Output {
-		&mut (**self)[range]
+where C: Cursor, T: BitStore {
+	fn index_mut(
+		&mut self,
+		range: RangeToInclusive<usize>,
+	) -> &mut Self::Output {
+		&mut self.as_mut_bitslice()[range]
 	}
 }
 
 impl<C, T> Neg for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = Self;
 
 	fn neg(mut self) -> Self::Output {
-		let _ = -(&mut *self);
+		let _ = self.as_mut_bitslice().neg();
 		self
 	}
 }
 
 impl<C, T> Not for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = Self;
 
 	fn not(mut self) -> Self::Output {
-		let _ = !(&mut *self);
+		let _ = self.as_mut_bitslice().not();
 		self
 	}
 }
 
 impl<C, T> Shl<usize> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = Self;
 
 	fn shl(mut self, shamt: usize) -> Self::Output {
@@ -906,14 +909,14 @@ where C: Cursor, T: Bits {
 }
 
 impl<C, T> ShlAssign<usize> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn shl_assign(&mut self, shamt: usize) {
-		**self <<= shamt;
+		self.as_mut_bitslice().shl_assign(shamt);
 	}
 }
 
 impl<C, T> Shr<usize> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Output = Self;
 
 	fn shr(mut self, shamt: usize) -> Self::Output {
@@ -923,52 +926,52 @@ where C: Cursor, T: Bits {
 }
 
 impl<C, T> ShrAssign<usize> for BitBox<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn shr_assign(&mut self, shamt: usize) {
-		**self >>= shamt;
+		self.as_mut_bitslice().shr_assign(shamt);
 	}
 }
 
 #[repr(C)]
 pub struct IntoIter<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	/// Owning pointer to the full slab
-	_original: BitBox<C, T>,
+	bitbox: BitBox<C, T>,
 	/// Slice descriptor for the region undergoing iteration.
-	iterator: BitPtr<T>,
+	region: BitPtr<T>,
 }
 
 impl<C, T> IntoIter<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn iterator(&self) -> <&BitSlice<C, T> as IntoIterator>::IntoIter {
-		<&BitSlice<C, T>>::from(self.iterator).into_iter()
+		self.region.into_bitslice().into_iter()
 	}
 }
 
 impl<C, T> DoubleEndedIterator for IntoIter<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	fn next_back(&mut self) -> Option<Self::Item> {
 		let mut slice_iter = self.iterator();
 		let out = slice_iter.next_back();
-		self.iterator = slice_iter.bitptr();
+		self.region = slice_iter.bitptr();
 		out
 	}
 }
 
 impl<C, T> ExactSizeIterator for IntoIter<C, T>
-where C: Cursor, T: Bits {}
+where C: Cursor, T: BitStore {}
 
 impl<C, T> FusedIterator for IntoIter<C, T>
-where C: Cursor, T: Bits {}
+where C: Cursor, T: BitStore {}
 
 impl<C, T> Iterator for IntoIter<C, T>
-where C: Cursor, T: Bits {
+where C: Cursor, T: BitStore {
 	type Item = bool;
 
 	fn next(&mut self) -> Option<Self::Item> {
 		let mut slice_iter = self.iterator();
 		let out = slice_iter.next();
-		self.iterator = slice_iter.bitptr();
+		self.region = slice_iter.bitptr();
 		out
 	}
 
@@ -983,7 +986,7 @@ where C: Cursor, T: Bits {
 	fn nth(&mut self, n: usize) -> Option<Self::Item> {
 		let mut slice_iter = self.iterator();
 		let out = slice_iter.nth(n);
-		self.iterator = slice_iter.bitptr();
+		self.region = slice_iter.bitptr();
 		out
 	}
 
