@@ -8,11 +8,11 @@ handle operations.
 !*/
 
 use crate::{
-	bits::{
-		BitIdx,
-		Bits,
-	},
 	pointer::BitPtr,
+	store::{
+		BitIdx,
+		BitStore,
+	},
 };
 
 /// Variant markers for the kinds of domains.
@@ -48,7 +48,7 @@ impl BitDomainKind {
 }
 
 impl<T> From<&BitPtr<T>> for BitDomainKind
-where T: Bits {
+where T: BitStore {
 	fn from(bitptr: &BitPtr<T>) -> Self {
 		let (e, h, t) = bitptr.region_data();
 		let w = T::BITS;
@@ -78,10 +78,10 @@ where T: Bits {
 ///
 /// # Type Parameters
 ///
-/// - `T: Bits` The type of the elements the domain inhabits.
+/// - `T: BitStore` The type of the elements the domain inhabits.
 #[derive(Clone, Debug)]
 pub enum BitDomain<'a, T>
-where T: 'a + Bits {
+where T: 'a + BitStore {
 	/// Empty domain.
 	Empty,
 	/// Single element domain which does not reach either edge.
@@ -95,7 +95,7 @@ where T: 'a + Bits {
 	/// # Invariants
 	///
 	/// - `.0` must satisfy `BitIdx::is_valid::<T>`
-	/// - `.1` must satisfy `BitIdx::is_valid_tail::<T>`
+	/// - `.2` must satisfy `BitIdx::is_valid_tail::<T>`
 	///
 	/// # Behavior
 	///
@@ -114,6 +114,11 @@ where T: 'a + Bits {
 	/// - `.3`: reference to the partial tail edge element
 	/// - `.4`: index of the first dead bit after the domain
 	///
+	/// # Invariants
+	///
+	/// - `.0` must satisfy `BitIdx::is_valid::<T>`
+	/// - `.4` must satisfy `BitIdx::is_valid_tail::<T>`
+	///
 	/// # Behavior
 	///
 	/// This variant is produced when the domain uses at least two elements, and
@@ -128,6 +133,10 @@ where T: 'a + Bits {
 	/// - `.1`: reference to the partial head element
 	/// - `.2`: reference to the full elements of the domain. This may be empty.
 	///
+	/// # Invariants
+	///
+	/// - `.0` must satisfy `BitIdx::is_valid::<T>`
+	///
 	/// # Behavior
 	///
 	/// This variant is produced when the domain’s head cursor is past `0`, and
@@ -141,6 +150,10 @@ where T: 'a + Bits {
 	/// - `.1`: reference to the partial tail element
 	/// - `.2`: index of the first dead bit after the live bits in the tail
 	///
+	/// # Invariants
+	///
+	/// - `.2` must satisfy `BitIdx::is_valid_tail::<T>`
+	///
 	/// # Behavior
 	///
 	/// This variant is produced when the domain’s head cursor is exactly `0`,
@@ -160,7 +173,7 @@ where T: 'a + Bits {
 }
 
 impl<'a, T> From<BitPtr<T>> for BitDomain<'a, T>
-where T: 'a + Bits {
+where T: 'a + BitStore {
 	fn from(bitptr: BitPtr<T>) -> Self {
 		use BitDomainKind as Bdk;
 		let (e, h, t) = bitptr.region_data();
@@ -191,10 +204,10 @@ where T: 'a + Bits {
 ///
 /// # Type Parameters
 ///
-/// - `T: Bits` The type of the elements the domain inhabits.
+/// - `T: BitStore` The type of the elements the domain inhabits.
 #[derive(Debug)]
 pub enum BitDomainMut<'a, T>
-where T: 'a + Bits {
+where T: 'a + BitStore {
 	/// Empty domain.
 	Empty,
 	/// Single element domain which does not reach either edge.
@@ -208,7 +221,7 @@ where T: 'a + Bits {
 	/// # Invariants
 	///
 	/// - `.0` must satisfy `BitIdx::is_valid::<T>`
-	/// - `.1` must satisfy `BitIdx::is_valid_tail::<T>`
+	/// - `.2` must satisfy `BitIdx::is_valid_tail::<T>`
 	///
 	/// # Behavior
 	///
@@ -227,6 +240,11 @@ where T: 'a + Bits {
 	/// - `.3`: mutable reference to the partial tail edge element
 	/// - `.4`: index of the first dead bit after the domain
 	///
+	/// # Invariants
+	///
+	/// - `.0` must satisfy `BitIdx::is_valid::<T>`
+	/// - `.4` must satisfy `BitIdx::is_valid_tail::<T>`
+	///
 	/// # Behavior
 	///
 	/// This variant is produced when the domain uses at least two elements, and
@@ -242,6 +260,10 @@ where T: 'a + Bits {
 	/// - `.2`: mutable reference to the full elements of the domain. This may
 	///   be empty.
 	///
+	/// # Invariants
+	///
+	/// - `.0` must satisfy `BitIdx::is_valid::<T>`
+	///
 	/// # Behavior
 	///
 	/// This variant is produced when the domain’s head cursor is past `0`, and
@@ -256,6 +278,10 @@ where T: 'a + Bits {
 	/// - `.1`: mutable reference to the partial tail element
 	/// - `.2`: index of the first dead bit after the live bits in the tail
 	///
+	/// # Invariants
+	///
+	/// - `.2` must satisfy `BitIdx::is_valid_tail::<T>`
+	///
 	/// # Behavior
 	///
 	/// This variant is produced when the domain’s head cursor is exactly `0`,
@@ -275,7 +301,7 @@ where T: 'a + Bits {
 }
 
 impl<'a, T> From<BitPtr<T>> for BitDomainMut<'a, T>
-where T: 'a + Bits {
+where T: 'a + BitStore {
 	fn from(bitptr: BitPtr<T>) -> Self {
 		use BitDomainKind as Bdk;
 		let (h, t) = bitptr.cursors();
