@@ -58,6 +58,7 @@ mod domain;
 mod pointer;
 pub mod prelude;
 pub mod slice;
+pub mod store;
 
 #[cfg(any(feature = "alloc", feature = "std"))]
 pub mod boxed;
@@ -75,11 +76,11 @@ mod serdes;
 #[cfg(feature = "testing")]
 pub mod testing {
 	pub use crate::{
-		bits::*,
 		domain::*,
 		macros::*,
 		pointer::*,
 		slice::*,
+		store::*,
 		vec::*,
 	};
 }
