@@ -7,13 +7,13 @@ work.
 !*/
 
 use crate::{
-	bits::{
-		BitIdx,
-		Bits,
-	},
 	cursor::Cursor,
 	domain::*,
 	slice::BitSlice,
+	store::{
+		BitIdx,
+		BitStore,
+	},
 };
 
 use core::{
@@ -57,7 +57,7 @@ const USZ_BITS: usize = size_of::<usize>() * 8;
 ///
 /// Don’t.
 #[doc(hidden)]
-pub union Pointer<T> {
+pub(crate) union Pointer<T> {
 	/// A read pointer to some data.
 	r: *const T,
 	/// A write pointer to some data.
@@ -248,7 +248,7 @@ element unavailable.
 
 # Type Parameters
 
-- `T: Bits` is the storage type over which the pointer governs.
+- `T: BitStore` is the storage type over which the pointer governs.
 
 # Safety
 
@@ -269,7 +269,7 @@ regime.
 #[repr(C)]
 #[derive(Clone, Copy, Eq, Hash, PartialEq, PartialOrd, Ord)]
 pub struct BitPtr<T = u8>
-where T: Bits {
+where T: BitStore {
 	_ty: PhantomData<T>,
 	/// Two-element bitfield structure, holding pointer and head information.
 	///
@@ -297,7 +297,7 @@ where T: Bits {
 }
 
 impl<T> BitPtr<T>
-where T: Bits {
+where T: BitStore {
 	/// The number of high bits in `self.ptr` that are actually the address of
 	/// the zeroth `T`.
 	pub const PTR_DATA_BITS: usize = PTR_BITS - Self::PTR_HEAD_BITS;
@@ -392,7 +392,7 @@ where T: Bits {
 	///
 	/// The provided pointer must be either null, or valid in the caller’s
 	/// memory model and allocation regime.
-	pub fn uninhabited(ptr: impl Into<Pointer<T>>) -> Self {
+	pub(crate) fn uninhabited(ptr: impl Into<Pointer<T>>) -> Self {
 		let ptr = ptr.into();
 		//  Check that the pointer is properly aligned for the storage type.
 		//  Null pointers are always well aligned.
@@ -418,9 +418,9 @@ where T: Bits {
 	///   then the empty-slice representation is returned, regardless of other
 	///   argument values.
 	/// - `elts`: A number of storage elements in the domain of the new
-	///   `BitPtr`. This number must be in `0 .. Self::MAX_ELTS`. If it is zero,
-	///   then the empty-slice representation is returned, regardless of other
-	///   argument values.
+	///   `BitPtr`. This number must be in `0 ..= Self::MAX_ELTS`. If it is
+	///   zero, then the empty-slice representation is returned, regardless of
+	///   other argument values.
 	/// - `head`: The bit index of the first live bit in the domain. This must
 	///   be in the domain `0 .. T::BITS`.
 	/// - `tail`: The bit index of the first dead bit after the domain. This
@@ -450,7 +450,7 @@ where T: Bits {
 	///
 	/// - If the `data` pointer is not aligned to at least the type `T`,
 	/// - If the `elts` counter is not within the countable elements domain,
-	///   `0 .. Self::MAX_ELTS`,
+	///   `0 ..= Self::MAX_ELTS`,
 	/// - If the `data` pointer is so high in the address space that addressing
 	///   the last element would cause the pointer to wrap,
 	/// - If `head` or `tail` are too large for indexing bits within `T`,
@@ -462,7 +462,7 @@ where T: Bits {
 	/// validly allocated, region of memory, or the canonical dangling pointer
 	/// and empty slice. The caller is responsible for ensuring that the slice
 	/// of memory that the new `BitPtr` will govern is all governable.
-	pub fn new(
+	pub(crate) fn new(
 		data: impl Into<Pointer<T>>,
 		elts: usize,
 		head: impl Into<BitIdx>,
@@ -485,7 +485,7 @@ where T: Bits {
 		//  Check that the slice domain is below the ceiling.
 		assert!(
 			elts <= Self::MAX_ELTS,
-			"{} exceeds the BitPtr domain maximum, {}",
+			"{} is outside the element count domain 1 ..= {}",
 			elts,
 			Self::MAX_ELTS,
 		);
@@ -494,7 +494,7 @@ where T: Bits {
 		assert!(
 			head.is_valid::<T>(),
 			"{} is outside the head domain 0 .. {}",
-			*head,
+			head,
 			T::BITS,
 		);
 
@@ -502,7 +502,7 @@ where T: Bits {
 		assert!(
 			tail.is_valid_tail::<T>(),
 			"{} is outside the tail domain 1 ..= {}",
-			*tail,
+			tail,
 			T::BITS,
 		);
 
@@ -520,7 +520,7 @@ where T: Bits {
 				tail.is_valid::<T>(),
 				"BitPtr domains with maximum elements must have the tail ({}) \
 				cursor in 1 .. {}",
-				*tail,
+				tail,
 				T::BITS,
 			);
 		}
@@ -606,7 +606,7 @@ where T: Bits {
 	///
 	/// This pointer must be valid in the user’s memory model and allocation
 	/// regime in order for the caller to dereference it.
-	pub fn pointer(&self) -> Pointer<T> {
+	pub(crate) fn pointer(&self) -> Pointer<T> {
 		(self.ptr.as_ptr() as usize & Self::PTR_DATA_MASK).into()
 	}
 
@@ -697,11 +697,12 @@ where T: Bits {
 	///
 	/// # Returns
 	///
-	/// - `Pointer<T>`: A well aligned pointer to the first element of the slice.
+	/// - `Pointer<T>`: A well aligned pointer to the first element of the
+	///   slice.
 	/// - `usize`: The number of elements in the slice.
 	/// - `BitIdx`: The index of the first live bit in the first element.
 	/// - `BitIdx`: The index of the first dead bit in the last element.
-	pub fn raw_parts(&self) -> (Pointer<T>, usize, BitIdx, BitIdx) {
+	pub(crate) fn raw_parts(&self) -> (Pointer<T>, usize, BitIdx, BitIdx) {
 		(self.pointer(), self.elements(), self.head(), self.tail())
 	}
 
@@ -1025,7 +1026,7 @@ where T: Bits {
 	where C: Cursor {
 		unsafe {
 			&*(slice::from_raw_parts(
-				self.ptr.as_ptr() as *const u8 as *const (),
+				Pointer::from(self.ptr.as_ptr()).r() as *const (),
 				self.len,
 			) as *const [()] as *const BitSlice<C, T>)
 		}
@@ -1060,7 +1061,7 @@ where T: Bits {
 /// Mutability is not encoded in the `BitPtr` type system at this time, and thus
 /// is not enforced by the compiler yet.
 impl<T> AsMut<[T]> for BitPtr<T>
-where T: Bits {
+where T: BitStore {
 	fn as_mut(&mut self) -> &mut [T] {
 		self.as_mut_slice()
 	}
@@ -1069,21 +1070,21 @@ where T: Bits {
 /// Gets read access to all elements in the underlying storage, including the
 /// partial head and tail elements.
 impl<T> AsRef<[T]> for BitPtr<T>
-where T: Bits {
+where T: BitStore {
 	fn as_ref(&self) -> &[T] {
 		self.as_slice()
 	}
 }
 
 impl<'a, C, T> From<&'a BitSlice<C, T>> for BitPtr<T>
-where C: Cursor, T: 'a + Bits {
+where C: Cursor, T: 'a + BitStore {
 	fn from(src: &'a BitSlice<C, T>) -> Self {
 		Self::from_bitslice(src)
 	}
 }
 
 impl<'a, C, T> From<&'a mut BitSlice<C, T>> for BitPtr<T>
-where C: Cursor, T: 'a + Bits {
+where C: Cursor, T: 'a + BitStore {
 	fn from(src: &'a mut BitSlice<C, T>) -> Self {
 		Self::from_bitslice(src)
 	}
@@ -1091,7 +1092,7 @@ where C: Cursor, T: 'a + Bits {
 
 /// Produces the empty-slice representation.
 impl<T> Default for BitPtr<T>
-where T: Bits {
+where T: BitStore {
 	/// Produces an empty-slice representation.
 	///
 	/// The empty slice has no size or cursors, and its pointer is the alignment
@@ -1104,26 +1105,29 @@ where T: Bits {
 
 /// Prints the `BitPtr` data structure for debugging.
 impl<T> Debug for BitPtr<T>
-where T: Bits {
+where T: BitStore {
 	fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-		struct HexPtr<T: Bits>(*const T);
-		impl<T: Bits> Debug for HexPtr<T> {
+		struct HexPtr<T: BitStore>(*const T);
+		impl<T: BitStore> Debug for HexPtr<T> {
 			fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-				f.write_fmt(format_args!("0x{:0>1$X}", self.0 as usize, PTR_BITS >> 2))
+				write!(f, "0x{:0>1$X}", self.0 as usize, PTR_BITS >> 2)
 			}
 		}
+
 		struct HexAddr(usize);
 		impl Debug for HexAddr {
 			fn fmt(&self, f: &mut Formatter) -> fmt::Result {
 				f.write_fmt(format_args!("{:#X}", self.0))
 			}
 		}
-		struct BinAddr<T: Bits>(BitIdx, PhantomData<T>);
-		impl<T: Bits>  Debug for BinAddr<T> {
+
+		struct BinAddr<T: BitStore>(BitIdx, PhantomData<T>);
+		impl<T: BitStore>  Debug for BinAddr<T> {
 			fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-				f.write_fmt(format_args!("0b{:0>1$b}", *self.0, T::INDX as usize))
+				write!(f, "0b{:0>1$b}", *self.0, T::INDX as usize)
 			}
 		}
+
 		write!(f, "BitPtr<{}>", T::TYPENAME)?;
 		f.debug_struct("")
 			.field("data", &HexPtr::<T>(self.pointer().r()))
